==> add-content-workflow-angularjs-1.5.0.tgz: package/source/app/add-content-details-form/add-content-details-form.component.ts <==
import * as angular from 'angular';
import './add-content-details-form.component.less';

export default class AddContentDetailsFormComponent {
    workflow: any;
    content: any;
    static config = {
        selector: 'addContentDetailsForm',
        template: `
            <div layout="column">
                <form name="detailsForm" id="detailsForm" layout="column">
                    <md-input-container md-is-error="$ctrl.workflow.hasError('url')" layout="row">
                        <div flex> 
                            <label class="url-label">{{::$ctrl.AddContentTranslate.get('add-content-workflow__source-step--url')}}
                            </label>
                            <input ng-model="$ctrl.content.url" name="url" ng-required="true" ng-disabled="$ctrl.workflow.savingAddContent || !$ctrl.workflow.hasError('url') || $ctrl.workflow.skipChecked"/>
                            <div class="md-errors-spacer"></div>
                            <div ng-messages="$ctrl.workflow.validationErrors">
                            <div ng-message="url">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.url)}}</div>
                            </div>
                            <div class="add-content-workflow__details-step-indexed-document-container">
                                <span ng-if="$ctrl.content.existingDocument">{{$ctrl.translateIndexedTime()}}</span>
                                <span ng-if="$ctrl.content.existingDocument">
                                    <mw-icon svg-icon="action:ic_info_outline_24px"></mw-icon>
                                    <md-tooltip class="add-content-workflow__info-tooltip">
                                        {{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-one')}}<br>
                                        {{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-two')}}
                                        <ul>
                                            <li>{{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-bullet-one')}}</li>
                                            <li>{{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-bullet-two')}}</li>
                                        </ul>
                                        {{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-three')}}
                                    </md-tooltip>
                                </span>
                                <span class="add-content-workflow__details-step-scraped-document-text" ng-if="$ctrl.content.scrapedDocument">{{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-scraped')}}</span>
                            </div>
                        </div>
                        <a class="add-content-details-step__icon-open" ng-href={{$ctrl.content.url}} target="_blank">
                            <mw-icon svg-icon="action:ic_open_in_new_24px"></mw-icon>
                        </a>  
                    </md-input-container>
                    <md-input-container ng-if="$ctrl.workflow.shouldHideField('title', $ctrl.content.mediaType)" md-is-error="$ctrl.workflow.hasError('title')">
                        <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--title-label')}}</label>
                        <input ng-model="$ctrl.content.title" name="title" ng-required="$ctrl.workflow.isFieldRequired('title', $ctrl.content.mediaType)" ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked" maxlength="140" md-maxlength="140" />
                        <div class="md-errors-spacer"></div>
                        <div ng-messages="$ctrl.workflow.validationErrors">
                            <div ng-message="title">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.title)}}</div>
                        </div>
                    </md-input-container>
                    <md-input-container md-is-error="$ctrl.workflow.hasError('description')">
                        <label>{{$ctrl.AddContentTranslate.get($ctrl.workflow.getLabelAlias('description', $ctrl.content.mediaType) || 'add-content-workflow__details-step--description-label')}}</label>
                        <textarea ng-model="$ctrl.content.description" md-maxlength="1000" maxlength="1000" rows="1" md-select-on-focus="" ng-required="$ctrl.workflow.isFieldRequired('description', $ctrl.content.mediaType)" ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"></textarea>
                        <div class="md-errors-spacer"></div>
                        <div ng-messages="$ctrl.workflow.validationErrors">
                            <div ng-message="description">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.description)}}</div>
                        </div>
                    </md-input-container>
                    <div layout="row">
                        <md-input-container flex style="margin-right:36px;" md-is-error="$ctrl.workflow.hasError('imageUrl')">
                            <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--image-url-label')}}</label>
                            <input ng-model="$ctrl.content.imageUrl" name="imageUrl" ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked" />
                            <div class="md-errors-spacer"></div>
                            <div ng-messages="$ctrl.workflow.validationErrors">
                                <div ng-message="imageUrl">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.imageUrl)}}</div>
                            </div>
                        </md-input-container>
                        <md-input-container flex md-is-error="$ctrl.workflow.hasError('author')">
                            <label>{{$ctrl.AddContentTranslate.get($ctrl.workflow.getLabelAlias('author', $ctrl.content.mediaType) || 'add-content-workflow__details-step--author-label')}}</label>
                            <input 
                                name="author" 
                                ng-model="$ctrl.content.author" 
                                ng-required="$ctrl.workflow.isFieldRequired('author', $ctrl.content.mediaType)" 
                                ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"/>
                            <div class="md-errors-spacer"></div>
                            <div ng-messages="$ctrl.workflow.validationErrors">
                              <div ng-message="author">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.author)}}</div>
                            </div>
                        </md-input-container>
                    </div>
                    <div layout="row">
                        <md-input-container ng-if="$ctrl.workflow.shouldHideField('source', $ctrl.content.mediaType)" flex style="margin-right:36px;"  md-is-error="$ctrl.workflow.hasError('source')">
                            <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--source-label')}}</label>
                            <input 
                                name="source" 
                                ng-model="$ctrl.content.publisher" 
                                ng-required="$ctrl.workflow.isFieldRequired('source', $ctrl.content.mediaType)" 
                                ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"/>
                            <div class="md-errors-spacer"></div>
                            <div ng-messages="$ctrl.workflow.validationErrors">
                              <div ng-message="source">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.source)}}</div>
                            </div>
                        </md-input-container>
                        <md-input-container flex>
                            <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--source-country-label')}}</label>
                            <md-select ng-model="$ctrl.content.countryCode" ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked">
                                <md-option ng-repeat="country in $ctrl.workflow.countries" ng-value="country.code">{{$ctrl.AddContentTranslate.get(country.name)}}</md-option>
                            </md-select>
                            <div class="md-errors-spacer"></div>
                        </md-input-container>
                    </div>
                    <div layout="row">
                        <md-input-container flex>
                            <label>{{$ctrl.AddContentTranslate.get($ctrl.workflow.getLabelAlias('publishDate', $ctrl.content.mediaType) || 'add-content-workflow__details-step--publish-date-label')}}</label>
                            <mw-date-picker-dropdown
                                form-input-name="$ctrl.workflow.datepicker.formInputName"
                                is-required="true"
                                date="$ctrl.content.date"
                                locale="$ctrl.workflow.datePicker.locale"
                                min-view="$ctrl.workflow.datePicker.minView"
                                max-view="$ctrl.workflow.datePicker.maxView"
                                max-date="$ctrl.workflow.datePicker.maxDate"
                                label="$ctrl.workflow.datePicker.label"
                                format="$ctrl.workflow.datePicker.format"
                                timezone="$ctrl.workflow.datePicker.timezone"
                                on-date-selection="$ctrl.onDateChange($event)"
                                disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"
                            > 
                            </mw-date-picker-dropdown>
                        </md-input-container>
                    </div>
                    </div>
                </form>
            </div>
        `,
        controller: AddContentDetailsFormComponent,
        bindings: {
            workflow: '<',
            content: '<'
        }
    };

    /*@ngInject*/
    constructor(
        private AddContentTranslate,
        private $scope
    ) {
    }

    $onInit() {
        // Watch for change of the current document, reset the form state so no validation flags are present
        this.$scope.$watch(() => this.workflow.currentIndex, () => {
            this.$scope.detailsForm.$setPristine();
        })
    }
    translateIndexedTime(){
        let now = Date.now()
        let indexTime = (now - this.content.date) / 60000
        if(indexTime < 60){
            return this.AddContentTranslate.get('add-content-workflow__details-step-indexed--minutes', {
                indexTime: Math.round(indexTime)
            });
        }
        if(Math.floor(indexTime)/60 === 1 ){
            return this.AddContentTranslate.get('add-content-workflow__details-step-indexed--hour', {
                indexTime: 1
            })
        }
        if(indexTime < 60 * 48){
            return this.AddContentTranslate.get('add-content-workflow__details-step-indexed--hours', {
                indexTime: Math.round(indexTime/60)
            });
        }
        if(indexTime > 60 * 48){
            return this.AddContentTranslate.get('add-content-workflow__details-step-indexed--days', {
                indexTime: Math.round(indexTime/60/24)
            })
        }
    }

    onDateChange = ($ev) => {
        this.content.date = $ev.date;
    };
}

==> add-content-workflow-angularjs-1.5.1.tgz: package/source/app/add-content-details-form/add-content-details-form.component.ts <==
import * as angular from 'angular';
import './add-content-details-form.component.less';

export default class AddContentDetailsFormComponent {
    workflow: any;
    content: any;
    static config = {
        selector: 'addContentDetailsForm',
        template: `
            <div layout="column">
                <form name="detailsForm" id="detailsForm" layout="column">
                    <md-input-container md-is-error="$ctrl.workflow.hasError('url')" layout="row">
                        <div flex> 
                            <label class="url-label">{{::$ctrl.AddContentTranslate.get('add-content-workflow__source-step--url')}}
                            </label>
                            <input ng-model="$ctrl.content.url" name="url" ng-required="true" ng-disabled="$ctrl.workflow.savingAddContent || !$ctrl.workflow.hasError('url') || $ctrl.workflow.skipChecked"/>
                            <div class="md-errors-spacer"></div>
                            <div ng-messages="$ctrl.workflow.validationErrors">
                            <div ng-message="url">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.url)}}</div>
                            </div>
                            <div ng-if="!$ctrl.content.urlValidation" class="add-content-workflow__details-step-indexed-document-container">
                                <span ng-if="$ctrl.content.existingDocument">{{$ctrl.translateIndexedTime()}}</span>
                                <span ng-if="$ctrl.content.existingDocument">
                                    <mw-icon svg-icon="action:ic_info_outline_24px"></mw-icon>
                                    <md-tooltip class="add-content-workflow__info-tooltip">
                                        <div>
                                            <span>{{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-one')}}</span>
                                            <br></br>
                                            <span>{{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-two')}}</span>
                                            <ul>
                                                <li>{{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-bullet-one')}}</li>
                                                <li>{{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-bullet-two')}}</li>
                                            </ul>
                                            <br>
                                            {{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-indexed--info-tip-three')}}
                                        </div>
                                    </md-tooltip>
                                </span>
                                <span class="add-content-workflow__details-step-scraped-document-text" ng-if="$ctrl.content.scrapedDocument">{{$ctrl.AddContentTranslate.get('add-content-workflow__details-step-scraped')}}</span>
                            </div>
                        </div>
                        <a class="add-content-details-step__icon-open" ng-href={{$ctrl.content.url}} target="_blank">
                            <mw-icon class="md-primary" svg-icon="action:ic_open_in_new_24px"></mw-icon>
                        </a>  
                    </md-input-container>
                    <md-input-container ng-if="$ctrl.workflow.shouldHideField('title', $ctrl.content.mediaType)" md-is-error="$ctrl.workflow.hasError('title')">
                        <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--title-label')}}</label>
                        <input ng-model="$ctrl.content.title" name="title" ng-required="$ctrl.workflow.isFieldRequired('title', $ctrl.content.mediaType)" ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked" maxlength="140" md-maxlength="140" />
                        <div class="md-errors-spacer"></div>
                        <div ng-messages="$ctrl.workflow.validationErrors">
                            <div ng-message="title">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.title)}}</div>
                        </div>
                    </md-input-container>
                    <md-input-container md-is-error="$ctrl.workflow.hasError('description')">
                        <label>{{$ctrl.AddContentTranslate.get($ctrl.workflow.getLabelAlias('description', $ctrl.content.mediaType) || 'add-content-workflow__details-step--description-label')}}</label>
                        <textarea ng-model="$ctrl.content.description" md-maxlength="1000" maxlength="1000" rows="1" md-select-on-focus="" ng-required="$ctrl.workflow.isFieldRequired('description', $ctrl.content.mediaType)" ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"></textarea>
                        <div class="md-errors-spacer"></div>
                        <div ng-messages="$ctrl.workflow.validationErrors">
                            <div ng-message="description">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.description)}}</div>
                        </div>
                    </md-input-container>
                    <div layout="row">
                        <md-input-container flex style="margin-right:36px;" md-is-error="$ctrl.workflow.hasError('imageUrl')">
                            <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--image-url-label')}}</label>
                            <input ng-model="$ctrl.content.imageUrl" name="imageUrl" ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked" />
                            <div class="md-errors-spacer"></div>
                            <div ng-messages="$ctrl.workflow.validationErrors">
                                <div ng-message="imageUrl">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.imageUrl)}}</div>
                            </div>
                        </md-input-container>
                        <md-input-container flex md-is-error="$ctrl.workflow.hasError('author')">
                            <label>{{$ctrl.AddContentTranslate.get($ctrl.workflow.getLabelAlias('author', $ctrl.content.mediaType) || 'add-content-workflow__details-step--author-label')}}</label>
                            <input 
                                name="author" 
                                ng-model="$ctrl.content.author" 
                                ng-required="$ctrl.workflow.isFieldRequired('author', $ctrl.content.mediaType)" 
                                ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"/>
                            <div class="md-errors-spacer"></div>
                            <div ng-messages="$ctrl.workflow.validationErrors">
                              <div ng-message="author">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.author)}}</div>
                            </div>
                        </md-input-container>
                    </div>
                    <div layout="row">
                        <md-input-container ng-if="$ctrl.workflow.shouldHideField('source', $ctrl.content.mediaType)" flex style="margin-right:36px;"  md-is-error="$ctrl.workflow.hasError('source')">
                            <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--source-label')}}</label>
                            <input 
                                name="source" 
                                ng-model="$ctrl.content.publisher" 
                                ng-required="$ctrl.workflow.isFieldRequired('source', $ctrl.content.mediaType)" 
                                ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"/>
                            <div class="md-errors-spacer"></div>
                            <div ng-messages="$ctrl.workflow.validationErrors">
                              <div ng-message="source">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.source)}}</div>
                            </div>
                        </md-input-container>
                        <md-input-container flex>
                            <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--source-country-label')}}</label>
                            <md-select ng-model="$ctrl.content.countryCode" ng-disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked">
                                <md-option ng-repeat="country in $ctrl.workflow.countries" ng-value="country.code">{{$ctrl.AddContentTranslate.get(country.name)}}</md-option>
                            </md-select>
                            <div class="md-errors-spacer"></div>
                        </md-input-container>
                    </div>
                    <div layout="row">
                        <md-input-container flex>
                            <label>{{$ctrl.AddContentTranslate.get($ctrl.workflow.getLabelAlias('publishDate', $ctrl.content.mediaType) || 'add-content-workflow__details-step--publish-date-label')}}</label>
                            <mw-date-picker-dropdown
                                form-input-name="$ctrl.workflow.datepicker.formInputName"
                                is-required="true"
                                date="$ctrl.content.date"
                                locale="$ctrl.workflow.datePicker.locale"
                                min-view="$ctrl.workflow.datePicker.minView"
                                max-view="$ctrl.workflow.datePicker.maxView"
                                max-date="$ctrl.workflow.datePicker.maxDate"
                                label="$ctrl.workflow.datePicker.label"
                                format="$ctrl.workflow.datePicker.format"
                                timezone="$ctrl.workflow.datePicker.timezone"
                                on-date-selection="$ctrl.onDateChange($event)"
                                disabled="$ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"
                            > 
                            </mw-date-picker-dropdown>
                        </md-input-container>
                    </div>
                    </div>
                </form>
            </div>
        `,
        controller: AddContentDetailsFormComponent,
        bindings: {
            workflow: '<',
            content: '<'
        }
    };

    /*@ngInject*/
    constructor(
        private AddContentTranslate,
        private $scope
    ) {
    }

    $onInit() {
        // Watch for change of the current document, reset the form state so no validation flags are present
        this.$scope.$watch(() => this.workflow.currentIndex, () => {
            this.$scope.detailsForm.$setPristine();
        })
    }
    translateIndexedTime(){
        let now = Date.now()
        let indexTime = (now - this.content.date) / 60000
        if(indexTime < 60){
            return this.AddContentTranslate.get('add-content-workflow__details-step-indexed--minutes', {
                indexTime: Math.round(indexTime)
            });
        }
        if(Math.floor(indexTime)/60 === 1 ){
            return this.AddContentTranslate.get('add-content-workflow__details-step-indexed--hour', {
                indexTime: 1
            })
        }
        if(indexTime < 60 * 48){
            return this.AddContentTranslate.get('add-content-workflow__details-step-indexed--hours', {
                indexTime: Math.round(indexTime/60)
            });
        }
        if(indexTime > 60 * 48){
            return this.AddContentTranslate.get('add-content-workflow__details-step-indexed--days', {
                indexTime: Math.round(indexTime/60/24)
            })
        }
    }

    onDateChange = ($ev) => {
        this.content.date = $ev.date;
    };
}
